@@ -236,6 +236,10 @@ class VariantWriter(VariantParts):
                 "",
                 'extern "C" {',
                 "",
+                "#ifdef LT_VARIANT_INCLUDE",
+                "#include LT_VARIANT_INCLUDE",
+                "#endif",
+                "",
                 self.format_pins(),
                 "",
                 '} // extern "C"',
